@@ -1,28 +1,18 @@
 package App::optex::textconv::xls;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
-use v5.14;
+use strict;
 use warnings;
-use Carp;
-
-our @EXPORT_OK = qw(to_text);
-
-use App::optex::textconv::Converter 'import';
-
-our @CONVERTER = (
-    [ qr/\.xls$/ => \&to_text ],
-    );
 
 use Spreadsheet::ParseExcel;
 
 sub to_text {
     my $file = shift;
-    my $type = ($file =~ /\.(xls)$/)[0] or return;
     my $book = Spreadsheet::ParseExcel::Workbook->Parse($file) or return;
     my $worksheet = $book->{Worksheet} // return;
     my @sheets = @{$worksheet} or return;
-    join "\n\n", map sheet($_), @sheets;
+    join "\n", grep { defined and length } map sheet($_), @sheets;
 }
 
 sub sheet {
